@@ -728,6 +728,9 @@ class ValidatorMixin:
         """validate a tab using the provided scheme"""
         if tabname not in self._schemas:
             return Validation(None, True, {})
+        # if dataframe is empty, nothing to validate
+        if len(self._data[tabname]) == 0:
+            return Validation(self._data[tabname], True, {})
         schema = self._schemas[tabname]
         result = schema.validate_dataframe(self._data[tabname])
         return result
